/* This file is part of the KDE project
   Copyright (C) 2002 Simon Hausmann <hausmann@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#include "global.h"
#include "messagefactory.h"

using namespace IRC;

void IRC::initStatic()
{
    MessageFactory::self().registerMessageImpl<PassMessage>();
    MessageFactory::self().registerMessageImpl<NickMessage>();
    MessageFactory::self().registerMessageImpl<UserMessage>();
    MessageFactory::self().registerMessageImpl<ServerMessage>();
    MessageFactory::self().registerMessageImpl<OperMessage>();
    MessageFactory::self().registerMessageImpl<QuitMessage>();
    MessageFactory::self().registerMessageImpl<SquitMessage>();
    MessageFactory::self().registerMessageImpl<JoinMessage>();
    MessageFactory::self().registerMessageImpl<PartMessage>();
    MessageFactory::self().registerMessageImpl<ModeMessage>();
    MessageFactory::self().registerMessageImpl<TopicMessage>();
    MessageFactory::self().registerMessageImpl<NamesMessage>();
    MessageFactory::self().registerMessageImpl<ListMessage>();
    MessageFactory::self().registerMessageImpl<InviteMessage>();
    MessageFactory::self().registerMessageImpl<KickMessage>();
    MessageFactory::self().registerMessageImpl<VersionMessage>();
    MessageFactory::self().registerMessageImpl<StatsMessage>();
    MessageFactory::self().registerMessageImpl<LinksMessage>();
    MessageFactory::self().registerMessageImpl<TimeMessage>();
    MessageFactory::self().registerMessageImpl<ConnectMessage>();
    MessageFactory::self().registerMessageImpl<TraceMessage>();
    MessageFactory::self().registerMessageImpl<AdminMessage>();
    MessageFactory::self().registerMessageImpl<InfoMessage>();
    MessageFactory::self().registerMessageImpl<PrivmsgMessage>();
    MessageFactory::self().registerMessageImpl<NoticeMessage>();
    MessageFactory::self().registerMessageImpl<WhoMessage>();
    MessageFactory::self().registerMessageImpl<WhoisMessage>();
    MessageFactory::self().registerMessageImpl<WhowasMessage>();
    MessageFactory::self().registerMessageImpl<KillMessage>();
    MessageFactory::self().registerMessageImpl<PongMessage>();
    MessageFactory::self().registerMessageImpl<PingMessage>();
    MessageFactory::self().registerMessageImpl<ErrorMessage>();
    MessageFactory::self().registerMessageImpl<AwayMessage>();
    MessageFactory::self().registerMessageImpl<RehashMessage>();
    MessageFactory::self().registerMessageImpl<RestartMessage>();
    MessageFactory::self().registerMessageImpl<SummonMessage>();
    MessageFactory::self().registerMessageImpl<UsersMessage>();
    MessageFactory::self().registerMessageImpl<UserhostMessage>();
    MessageFactory::self().registerMessageImpl<IsonMessage>();

};

Person Person::fromMaskString( const QString &mask )
{
    // nick!user@host
    int emMarkPos = mask.find( '!' );
    int atPos = mask.find( '@' );

    if ( emMarkPos == -1 || atPos == -1 ||
        atPos < emMarkPos )
    return Person();

    QString nick = mask.left( emMarkPos );
    QString user = mask.mid( emMarkPos + 1, atPos - emMarkPos - 1 );
    QString host = mask.right( mask.length() - atPos - 1 );
    return Person( nick, user, QString::null /*realName*/, host );
}

void PersonData::copyFrom( const PersonData &other )
{
    m_nick = other.m_nick;
    m_user = other.m_user;
    m_realName = other.m_realName;
    m_host = other.m_host;
    m_ircServer = other.m_ircServer;
    m_ircOp = other.m_ircOp;
    m_awayMessage = other.m_awayMessage;
    m_idleTime = other.m_idleTime;
    m_channels = other.m_channels;
}

QStringList IRC::splitStringListObeyingQuotes( QChar separator, const QString &_text )
{
    QString text = _text;
    uint i = 0;
    uint startIndex = 0;
    QChar quoteChar;
    QStringList lst;

    while ( i < text.length() ) {
        QChar currentChar = text[ i ];

        if ( !quoteChar.isNull() && currentChar != quoteChar ) {
            ++i;
            continue;
        }

        if ( !quoteChar.isNull() ) {
            text.remove( i, 1 );
            quoteChar = QChar();
            currentChar = text[ i ];
        }

        if ( currentChar == '\"' || currentChar == '\'' ) {
            quoteChar = currentChar;

            text.remove( i, 1 );
            continue;
        }

        if ( currentChar != separator ) {
            ++i;
            continue;
        }

        int len = i - startIndex;
        if ( len > 0 ) 
            lst << text.mid( startIndex, len );

        ++i;
        startIndex = i;
    }

    int len = i - startIndex;
    if ( len > 0 ) 
        lst << text.mid( startIndex, len );

    return lst;
}

/* vim: et sw=4 ts=4
 */
